@@ -3,7 +3,8 @@ import { DataItem } from './DataItem';
 
 export const renderDataItems = (fields, patient, getLocalisation, getTranslation, fontSize = 9) => {
   return fields.map(({ key, label: defaultLabel, accessor }) => {
-    const value = (accessor ? accessor(patient, getLocalisation) : patient[key]) || '';
+    const value =
+      (accessor ? accessor(patient, { getLocalisation, getTranslation }) : patient[key]) || '';
     const label =
       getTranslation(`general.localisedField.${key}.label.short`) ||
       getTranslation(`general.localisedField.${key}.label`) ||
